@@ -100,20 +100,17 @@ class SyncHandler:
         logger.info(text_center("sync start"))
         config = self.config
         os.chdir(self.work_root)
-
-        # 如果work仓库配置了remote，先pull一下
-        for remote in self.repo.remotes:
-            print(remote)
-        if 'origin' in self.repo.remotes:
-            try:
-                shell("git pull")
-            except Exception as e:
-                logger.warning('git pull failed')
-
+        # save_work_repo(self.repo, "save work repo before sync", self.config.options.push)
         is_init = False
         ref_count = sum(1 for ref in self.repo.refs)
         if ref_count > 0:
             # 判断这个仓库是否有过提交
+            try:
+                shell(f"git submodule foreach git checkout .")
+                shell(f"git submodule foreach git clean -f")
+            except Exception as e:
+                logger.warning('clean submodules failed')
+
             # 初始化一下子项目
             shell(f"git submodule update --init --recursive --progress")
             self.repo.iter_submodules()
@@ -222,7 +219,7 @@ class TaskExecutor:
 
     def pull_src_repo(self):
         logger.info(f"update src repo :{self.task_src.repo_ref.url}")
-        shell(f"cd {self.repo_src.working_dir} && git checkout {self.task_src.repo_ref.branch} && git pull")
+        shell(f"cd {self.repo_src.working_dir} && git checkout {self.task_src.repo_ref.branch} -f && git pull")
         logger.info(f"update submodule of src repo")
         shell(f"cd {self.repo_src.working_dir} && git submodule update --init --recursive --progress ")
         logger.info(f"update src repo success")
@@ -237,7 +234,6 @@ class TaskExecutor:
             raise Exception(
                 f"The src repo dir <{dir_src_sync}> is empty. It may not be fully initialized. Try to enter this directory and execute the [git pull] command")
 
-        remove_target_dir = True
         if is_first:
             # 第一次同步，目标目录必须为空
             target_is_blank = is_blank_dir(dir_target_sync)
@@ -264,11 +260,9 @@ class TaskExecutor:
                     target_is_blank = is_blank_dir(dir_target_sync)
                     if not target_is_blank:
                         logger.warning(
-                            f"The target repository directory <{dir_target_sync}> is still not empty, Some changes may be lost!!!")
-                        # 此时不移除目标目录
-                        remove_target_dir = False
+                            f"The target repository directory <{dir_target_sync}> is still not empty, Some changes maybe lost !!!")
 
-        if remove_target_dir and os.path.exists(dir_target_sync):
+        if self.task_target.remove_dir_before_copy and os.path.exists(dir_target_sync):
             logger.info(f"remove <{dir_target_sync}> ...")
             shutil.rmtree(dir_target_sync)
             time.sleep(0.2)
